@@ -1,4 +1,5 @@
-""" This module provides you with useful date utility functions in the Chinese financial market for more convenient research purpose.
+
+""" This module offers useful date utility functions in the Chinese financial market for more convenient research purpose.
 
 """
 
@@ -35,7 +36,7 @@ def get_weekday_in_month(year, month, number_of_week, weekday):
     """ get the nth weekday in month
 
     :param year: year number, 'yyyy'
-    :type year：int
+    :type year: int
     :param month: month number, 1-12
     :type month: int
     :param number_of_week: number of the week
