@@ -1,9 +1,10 @@
 
 """ Current Commodity Option T-type Quotation
 
-For the convenience of future research, Raw data is parsed and re-formulated as T-type quotation.
+For the convenience of future research, raw data is parsed and re-formulated as T-type quotation.
 
 The format of T-type quotation data:
+
 - date, strike, the latest price of call option, the latest price of put option, underlying code, expiry date
 """
 
@@ -160,7 +161,7 @@ def get_commodity_option_quotes(exchange_name, calendar = optshare.Calendar(), d
 
     :param exchange_name: exchange name
     :type exchange_name: str
-    :param calendar: define transaction calendar
+    :param calendar: define transaction calendar, default value is optshare.Calendar()
     :type calendar: optshare.Calendar object
     :param display: Determine whether to display the variety of option quotes when fetching data
     :return: Supported commodity option t-quotes in given exchange name
