@@ -1,9 +1,10 @@
 
 """ Current Financial Option T-type Quotation
 
-For the convenience of future research, Raw data is parsed and re-formulated as T-type quotation.
+For the convenience of future research, raw data is parsed and re-formulated as T-type quotation.
 
 The format of T-type quotation data:
+
 - date, strike, the latest price of call option, latest price of put option, underlying code, the latest price of underlying, expiry date
 """
 
@@ -169,7 +170,7 @@ def get_financial_option_quotes(exchange_name, calendar = optshare.Calendar(), d
 
     :param exchange_name: exchange name
     :type exchange_name: str
-    :param calendar: define transaction calendar, default optshare.Calendar
+    :param calendar: define transaction calendar, default value is optshare.Calendar()
     :type calendar: optshare.Calendar object
     :param display: Determine whether to display the variety of option quotes when fetching data
     :return: Supported financial option t-quotes in given exchange name
